@@ -15,7 +15,7 @@ test_that("SER_posterior_e_loglik_rss (lambda = 0) agrees with previous version"
 
   res = SER_posterior_e_loglik_rss(R, Sigma, z,Ez,Ez2)
 
-  expect_equal(res, original.res, tol=1E-4)
+  expect_equal(res, original.res, tolerance=1e-4)
 }))
 
 test_that("SER_posterior_e_loglik_rss (lambda = 1) agrees with previous version", with(simulate(200, 500), {
@@ -33,5 +33,5 @@ test_that("SER_posterior_e_loglik_rss (lambda = 1) agrees with previous version"
 
   res = SER_posterior_e_loglik_rss(R, Sigma, z,Ez,Ez2)
 
-  expect_equal(res, original.res, tol=1E-4)
+  expect_equal(res, original.res, tolerance=1e-4)
 }))
